# SATURN TOOLBOX
`saturn-toolbox` is a free open source toolbox, that has many tools for resllers!

## Installation
Run `pip install saturn-toolbox`, the command `saturn-toolbox` should now be available.

## Contact
Join us on [discord](https://discord.com/invite/KNfnJzx)! 
## Support
If you encounter a problem, please feel free to open an issue here on github.

## TODO
- [ ] Export usable API
- [ ] Proper CLI command